==> kdevelop-3.0a3.tar.bz2: kdevelop-3.0a3/parts/classview/classactions.h <==
/***************************************************************************
 *   Copyright (C) 1999 by Jonas Nordin                                    *
 *   jonas.nordin@syncom.se                                                *
 *   Copyright (C) 2000-2001 by Bernd Gehrmann                             *
 *   bernd@kdevelop.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _CLASSACTION_H_
#define _CLASSACTION_H_

#include <kaction.h>
#include <kdeversion.h>

class KDevPlugin;
class QComboBox;

#if !(KDE_VERSION > 305)
#include <qguardedptr.h>
//--------------------begin-of-copy-of-kde-3.1-----------
/**
 * An action that automatically embeds a widget into a
 * toolbar.
 */
class KWidgetAction : public KAction
{
    Q_OBJECT
public:
    /**
     * Create an action that will embed widget into a toolbar
     * when plugged. This action may only be plugged into
     * a toolbar.
     */
    KWidgetAction( QWidget* widget, const QString& text,
                   const KShortcut& cut,
                   const QObject* receiver, const char* slot,
                   KActionCollection* parent, const char* name );
    virtual ~KWidgetAction();

    /**
     * Returns the widget associated with this action.
     */
    QWidget* widget() { return m_widget; }

    void setAutoSized( bool );

    /**
     * Plug the action. The widget passed to the constructor
     * will be reparented to w, which must inherit KToolBar.
     */
    virtual int plug( QWidget* w, int index = -1 );
    /**
     * Unplug the action. Ensures that the action is not
     * destroyed. It will be hidden and reparented to 0L instead.
     */
    virtual void unplug( QWidget *w );
private:
    QGuardedPtr<QWidget> m_widget;
    bool                 m_autoSized;
protected:
    virtual void virtual_hook( int id, void* data );
private:
    class KWidgetActionPrivate;
    KWidgetActionPrivate *d;
};

//--------------------end-of-copy-of-kde-3.1-----------
#endif // !(KDE_VERSION > 305)

class ClassListAction : public KWidgetAction
{
public:
    ClassListAction( KDevPlugin *part, const QString &text, const KShortcut& cut,
                     const QObject *receiver, const char *slot,
                     KActionCollection *parent, const char *name );
    void setCurrentClassName(const QString &name);
    QString currentClassName();
    void refresh();
    
private:
    QString currentText(); // only here for preventing its public use
    void setCurrentItem(const QString &item);
    KDevPlugin *m_part;
    QComboBox* m_combo;
};


class MethodListAction : public KWidgetAction
{
public:
    MethodListAction( KDevPlugin *part, const QString &text, const KShortcut& cut,
                      const QObject *receiver, const char *slot,
                      KActionCollection *parent, const char *name );
    void refresh(const QString &className);
    QString currentMethodName();
    
private:
    QString currentText(); // only here for preventing its public use
    KDevPlugin *m_part;
    QComboBox* m_combo;
};


class DelayedPopupAction : public KAction
{
    Q_OBJECT

public:
    DelayedPopupAction( const QString &text, const QString &pix, const KShortcut& cut,
                        QObject *receiver, const char *slot,
                        KActionCollection *parent, const char* name );
    ~DelayedPopupAction();
    
    virtual int plug(QWidget *widget, int index=-1);
    virtual void unplug(QWidget *widget);

    QPopupMenu *popupMenu();

private:
    QPopupMenu *m_popup;
};

#endif

==> kdevelop-3.0.0a6.tar.bz2: kdevelop-3.0.0a6/parts/classview/classactions.h <==
/***************************************************************************
 *   Copyright (C) 1999 by Jonas Nordin                                    *
 *   jonas.nordin@syncom.se                                                *
 *   Copyright (C) 2000-2001 by Bernd Gehrmann                             *
 *   bernd@kdevelop.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _CLASSACTION_H_
#define _CLASSACTION_H_

#include <kaction.h>
#include <kdeversion.h>

#if KDE_VERSION <= 305
#include <kdevwidgetaction.h>
using namespace KDevCompat;
#endif

class KDevPlugin;
class QComboBox;

class DelayedPopupAction : public KAction
{
    Q_OBJECT

public:
    DelayedPopupAction( const QString &text, const QString &pix, const KShortcut& cut,
                        QObject *receiver, const char *slot,
                        KActionCollection *parent, const char* name );
    ~DelayedPopupAction();

    virtual int plug(QWidget *widget, int index=-1);
    virtual void unplug(QWidget *widget);

    QPopupMenu *popupMenu();

private:
    QPopupMenu *m_popup;
};

#endif
